{g-vars.i &vsh = "shared"}
{show-header-frame-def.i}

screen-title = "Room Rates".

def new shared var current-floor-no as int init 1.
def new shared var current-room-type as int init ?.

def var i as int.
def buffer b-rate for rate.
def buffer b-rate2 for rate.
def var pop-prog as log init true.

def temp-table t-floor field floor like room.floor.
def temp-table t-room-type field type like room.type-of-room field name as char format "x(20)"  label "Room Type".

do i = 1 to total-floor-no transaction:
   create t-floor.
   t-floor.floor = i.
end.

do i = 1 to extent(room-types) transaction:
   create t-room-type.
   t-room-type.type = i.
   t-room-type.name = room-types[i].
end.


def var r-rate like rate.rate.
def var r-s-date like rate.start-date.
def var r-e-date like rate.end-date.

form t-floor.floor skip
     t-room-type.name skip
     r-s-date skip
     r-e-date validate (r-e-date <> ? and r-e-date >= r-s-date:input-value, "End date must be after start date!") 
     skip
     r-rate skip
     with frame f-u-rate
          view-as dialog-box
          title "Enter rate interval"
          centered side-labels.
             
def query q-room for t-floor, t-room-type, rate.

def browse brws query q-room
   display t-floor.floor
           t-room-type.name
           rate.start-date
           rate.end-date
           rate.rate format "$>>>,>>9.99"
   with 16 down.

form brws with frame f-rates size 80 by 20 at row 2 col 1 no-box.

procedure refresh.
   {show-header.i}
   
   browse brws:title = (if current-floor-no = ? then "All Floors" else "Floor " + string(current-floor-no)) +
                      " - " + (if current-room-type = ? then "All Room Types" else room-types[current-room-type]).

   open query q-room
      for each t-floor where (if current-floor-no = ? then true else t-floor.floor = current-floor-no),
         each t-room-type where (if current-room-type = ? then true else t-room-type.type = current-room-type),
         each rate where rate.floor = t-floor.floor and
                         rate.type-of-room = t-room-type.type
                   outer-join
                   use-index idx-rate-e-date.
/*
   def var q-row as int.
   q-row = current-result-row(query q-room).

   reposition q-room row q-row.
*/
   display brws with frame f-rates.
   brws:refresh().

   hide message no-pause.
   message "(A)dd   (C)hange   (S)et Floor   Set Room (T)ype".
   message "Cop(Y) to Floor   (O)utput   (R)eturn".
end.

on "y", "Y" anywhere do:
   def var f-from as int label "From Floor" format "9".
   def var f-to as int label "To Floor" format "9".
   
   f-from = current-floor-no.
   f-to = 1.
   
   form f-from skip
        f-to
        with frame f-copy side-labels title "Copy Rates" centered overlay row 5.
   
   repeat on endkey undo, leave on error undo, leave transaction:
      update f-from f-to validate(f-to <> f-from, "Floors must be different!") with frame f-copy.
   
      if f-from = ? or 
         f-to = ? or 
         not(f-from >= 1 and f-from <= total-floor-no) or 
         not(f-to >= 1 and f-to <= total-floor-no)
         then undo, next.
   
      for each b-rate where b-rate.floor = f-to:
         delete b-rate.
      end.
   
      for each b-rate where b-rate.floor = f-from:
         create b-rate2.
         buffer-copy b-rate to b-rate2.
         b-rate2.floor = f-to.
      end.
      
      message "Copied all rates from floor" f-from "to floor" f-to view-as alert-box.
      
      leave.
   end.
   
   hide frame f-copy no-pause.
   
   run refresh.
end.

on "a", "A" anywhere do:
   do transaction on endkey undo, leave:
      /* find last rate after which to add */
      find last b-rate
         where b-rate.floor = rate.floor and
               b-rate.type-of-room = rate.type-of-room
         use-index idx-rate-s-date no-lock no-error.
       
      if avail b-rate then do:
         r-rate = b-rate.rate.
         r-s-date = b-rate.end-date + 1.
         r-e-date = ?.
         
         display t-floor.floor t-room-type.name r-s-date r-e-date r-rate with frame f-u-rate.
         
         update r-e-date r-rate with frame f-u-rate.
      end.
      else do:
         r-s-date = today.
         r-rate = 0.
   
         display t-floor.floor t-room-type.name r-s-date r-e-date r-rate with frame f-u-rate.
   
         update r-s-date r-e-date r-rate with frame f-u-rate.
      end.
   
      create b-rate.
      b-rate.floor = t-floor.floor.
      b-rate.type-of-room = t-room-type.type.
      b-rate.rate = r-rate.
      b-rate.start-date = r-s-date.
      b-rate.end-date = r-e-date.
      release b-rate.
   end.
   
   run refresh.
end.

on "c", "C" anywhere do:
   if not avail(rate) then do:
      message "Add a rate for this floor and room-type before changing!" view-as alert-box.
      run refresh.
      return.
   end.
   
   if rate.end-date < today
   then do:
      message "Can not modify a rate in the past!".
      run refresh.
      return.
   end.
   
   do transaction on endkey undo, leave:
      r-s-date = (if rate.start-date >= today then rate.start-date else today).
      r-e-date = rate.end-date.
      r-rate = rate.rate.
   
      display t-floor.floor t-room-type.name r-s-date r-e-date r-rate with frame f-u-rate.
   
      update r-rate with frame f-u-rate.
   
      /* check if rate changed */
      if r-rate = rate.rate then do: run refresh. return. end.
   
      find b-rate where recid(b-rate) = recid(rate) exclusive-lock.

      if rate.start-date >= today then do:
         b-rate.rate = r-rate.
      end.
      else do:
         b-rate.end-date = r-s-date - 1.
         
         create b-rate.
         b-rate.floor = rate.floor.
         b-rate.type-of-room = rate.type-of-room.
         b-rate.rate = r-rate.
         b-rate.start-date = r-s-date.
         b-rate.end-date = r-e-date.
      end.

      release b-rate.
   end.
   
   run refresh.
end.

on "s", "S" anywhere do:
   {set_floor_number.i}
   run refresh.
end.

on "t", "T" anywhere do:
   {set_room_type.i}
   current-floor-no = ?.
   run refresh.
end.

on "o", "O" anywhere do:
   publish "push-program" ("rates-report.p").
   pop-prog = false.
   apply "r" to frame f-rates.
end.

run refresh.

enable brws with frame f-rates.

do on endkey undo, leave:
   wait-for "r", "R" of frame f-rates.
end.

if pop-prog then publish "pop-program".