package com.goldencode.hotel.dmo.hotel.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.hotel.dmo.hotel.*;

/**
 * Data Model Object corresponding with table <code>hotel.guest</code> (previously
 * <code>hotel.guest</code>).
 */
@LegacyTable(name = "guest", table = "guest")
@LegacyIndexes(
{
   @LegacyIndex(name = "idx-g-id", converted = "guest_idx_g_id", primary = true, unique = true, components = 
   {
      @LegacyIndexComponent(fieldName = "guest-id")
   })
})
public class GuestImpl
implements Serializable,
           Persistable,
           Guest
{
   /** Surrogate primary key */
   private Long id = null;

   /** Guest ID */
   @LegacyField(fieldId = 1, name = "guest-id", format = ">,>>>,>>9", initial = "0", columnLabel = "Guest ID", label = "Guest ID", order = 10, position = 2)
   private final integer guestId;

   /** First Name */
   @LegacyField(fieldId = 2, name = "first-name", format = "x(25)", columnLabel = "First Name", label = "First Name", order = 20, position = 3)
   private final character firstName;

   /** Last Name */
   @LegacyField(fieldId = 3, name = "last-name", format = "x(25)", columnLabel = "Last Name", label = "Last Name", order = 30, position = 4)
   private final character lastName;

   /** ID Type */
   @LegacyField(fieldId = 4, name = "id-type", format = "9", initial = "0", columnLabel = "ID Type", label = "ID Type", order = 40, position = 5)
   private final integer idType;

   /** ID Number */
   @LegacyField(fieldId = 5, name = "id-number", format = "x(20)", columnLabel = "ID Number", label = "ID Number", order = 50, position = 6)
   private final character idNumber;

   /** Date of Birth */
   @LegacyField(fieldId = 6, name = "date-of-birth", format = "99/99/99", initial = "?", columnLabel = "Date of Birth", label = "Date of Birth", order = 60, position = 7)
   private final date dateOfBirth;

   /** Phone # */
   @LegacyField(fieldId = 7, name = "phone-number", format = "(999)999-9999", columnLabel = "Phone #", label = "Phone #", order = 70, position = 8)
   private final character phoneNumber;

   /** Country */
   @LegacyField(fieldId = 8, name = "country", format = "x(25)", columnLabel = "Country", label = "Country", order = 80, position = 9)
   private final character country;

   /** City */
   @LegacyField(fieldId = 9, name = "city", format = "x(25)", columnLabel = "City", label = "City", order = 90, position = 10)
   private final character city;

   /** Street 2 */
   @LegacyField(fieldId = 10, name = "street-2", format = "x(25)", columnLabel = "Street 2", label = "Street 2", order = 100, position = 11)
   private final character street2;

   /** Street 1 */
   @LegacyField(fieldId = 11, name = "street-1", format = "x(25)", columnLabel = "Street 2", label = "Street 1", order = 110, position = 12)
   private final character street1;

   /** State/Province */
   @LegacyField(fieldId = 12, name = "state", format = "x(25)", columnLabel = "State/Province", label = "State/Province", order = 120, position = 13)
   private final character state;

   /** Postal Code */
   @LegacyField(fieldId = 13, name = "zip", format = "x(10)", columnLabel = "Postal Code", label = "Postal Code", order = 130, position = 14)
   private final character zip;

   /**
    * Default constructor.
    */
   public GuestImpl()
   {
      guestId = new integer(0);
      firstName = new character("");
      lastName = new character("");
      idType = new integer(0);
      idNumber = new character("");
      dateOfBirth = new date();
      phoneNumber = new character("");
      country = new character("");
      city = new character("");
      street2 = new character("");
      street1 = new character("");
      state = new character("");
      zip = new character("");
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new GuestImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from the given, backup
    * instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      GuestImpl from = (GuestImpl) old;
      setId(from.id);
      setGuestId(from.guestId);
      setFirstName(from.firstName);
      setLastName(from.lastName);
      setIdType(from.idType);
      setIdNumber(from.idNumber);
      setDateOfBirth(from.dateOfBirth);
      setPhoneNumber(from.phoneNumber);
      setCountry(from.country);
      setCity(from.city);
      setStreet2(from.street2);
      setStreet1(from.street1);
      setState(from.state);
      setZip(from.zip);
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Guest ID
    * 
    * @return  Guest ID
    */
   public integer getGuestId()
   {
      return (new integer(guestId));
   }

   /**
    * Setter: Guest ID
    * 
    * @param   guestId
    *          Guest ID
    */
   public void setGuestId(NumberType guestId)
   {
      this.guestId.assign(guestId);
   }

   /**
    * Getter: First Name
    * 
    * @return  First Name
    */
   public character getFirstName()
   {
      return (new character(firstName));
   }

   /**
    * Setter: First Name
    * 
    * @param   firstName
    *          First Name
    */
   public void setFirstName(Text firstName)
   {
      this.firstName.assign(firstName);
   }

   /**
    * Getter: Last Name
    * 
    * @return  Last Name
    */
   public character getLastName()
   {
      return (new character(lastName));
   }

   /**
    * Setter: Last Name
    * 
    * @param   lastName
    *          Last Name
    */
   public void setLastName(Text lastName)
   {
      this.lastName.assign(lastName);
   }

   /**
    * Getter: ID Type
    * 
    * @return  ID Type
    */
   public integer getIdType()
   {
      return (new integer(idType));
   }

   /**
    * Setter: ID Type
    * 
    * @param   idType
    *          ID Type
    */
   public void setIdType(NumberType idType)
   {
      this.idType.assign(idType);
   }

   /**
    * Getter: ID Number
    * 
    * @return  ID Number
    */
   public character getIdNumber()
   {
      return (new character(idNumber));
   }

   /**
    * Setter: ID Number
    * 
    * @param   idNumber
    *          ID Number
    */
   public void setIdNumber(Text idNumber)
   {
      this.idNumber.assign(idNumber);
   }

   /**
    * Getter: Date of Birth
    * 
    * @return  Date of Birth
    */
   public date getDateOfBirth()
   {
      return (new date(dateOfBirth));
   }

   /**
    * Setter: Date of Birth
    * 
    * @param   dateOfBirth
    *          Date of Birth
    */
   public void setDateOfBirth(date dateOfBirth)
   {
      this.dateOfBirth.assign(dateOfBirth);
   }

   /**
    * Getter: Phone #
    * 
    * @return  Phone #
    */
   public character getPhoneNumber()
   {
      return (new character(phoneNumber));
   }

   /**
    * Setter: Phone #
    * 
    * @param   phoneNumber
    *          Phone #
    */
   public void setPhoneNumber(Text phoneNumber)
   {
      this.phoneNumber.assign(phoneNumber);
   }

   /**
    * Getter: Country
    * 
    * @return  Country
    */
   public character getCountry()
   {
      return (new character(country));
   }

   /**
    * Setter: Country
    * 
    * @param   country
    *          Country
    */
   public void setCountry(Text country)
   {
      this.country.assign(country);
   }

   /**
    * Getter: City
    * 
    * @return  City
    */
   public character getCity()
   {
      return (new character(city));
   }

   /**
    * Setter: City
    * 
    * @param   city
    *          City
    */
   public void setCity(Text city)
   {
      this.city.assign(city);
   }

   /**
    * Getter: Street 2
    * 
    * @return  Street 2
    */
   public character getStreet2()
   {
      return (new character(street2));
   }

   /**
    * Setter: Street 2
    * 
    * @param   street2
    *          Street 2
    */
   public void setStreet2(Text street2)
   {
      this.street2.assign(street2);
   }

   /**
    * Getter: Street 1
    * 
    * @return  Street 1
    */
   public character getStreet1()
   {
      return (new character(street1));
   }

   /**
    * Setter: Street 1
    * 
    * @param   street1
    *          Street 1
    */
   public void setStreet1(Text street1)
   {
      this.street1.assign(street1);
   }

   /**
    * Getter: State/Province
    * 
    * @return  State/Province
    */
   public character getState()
   {
      return (new character(state));
   }

   /**
    * Setter: State/Province
    * 
    * @param   state
    *          State/Province
    */
   public void setState(Text state)
   {
      this.state.assign(state);
   }

   /**
    * Getter: Postal Code
    * 
    * @return  Postal Code
    */
   public character getZip()
   {
      return (new character(zip));
   }

   /**
    * Setter: Postal Code
    * 
    * @param   zip
    *          Postal Code
    */
   public void setZip(Text zip)
   {
      this.zip.assign(zip);
   }
}
