package com.goldencode.hotel.dmo.hotel.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.hotel.dmo.hotel.*;

/**
 * Data Model Object corresponding with table <code>hotel.rate</code> (previously
 * <code>hotel.rate</code>).
 */
@LegacyTable(name = "rate", table = "rate")
@LegacyIndexes(
{
   @LegacyIndex(name = "idx-rate-s-date", converted = "rate_idx_rate_s_date", primary = true, components = 
   {
      @LegacyIndexComponent(fieldName = "start-date")
   }),
   @LegacyIndex(name = "idx-rate-e-date", converted = "rate_idx_rate_e_date", components = 
   {
      @LegacyIndexComponent(fieldName = "end-date")
   })
})
public class RateImpl
implements Serializable,
           Persistable,
           Rate
{
   /** Surrogate primary key */
   private Long id = null;

   /** Type of Room */
   @LegacyField(fieldId = 1, name = "type-of-room", format = ">>9", initial = "0", columnLabel = "Type of Room", label = "Type of Room", mandatory = true, order = 10, position = 2)
   private final integer typeOfRoom;

   /** Floor */
   @LegacyField(fieldId = 2, name = "floor", format = ">>9", initial = "0", columnLabel = "Floor", label = "Floor", mandatory = true, order = 20, position = 3)
   private final integer floor;

   /** Rate */
   @LegacyField(fieldId = 3, name = "rate", format = "->>,>>9.99", initial = "0", columnLabel = "Rate", label = "Rate", mandatory = true, order = 30, position = 4)
   private final decimal rate;

   /** From Date */
   @LegacyField(fieldId = 4, name = "start-date", format = "99/99/99", initial = "?", columnLabel = "From Date", label = "From Date", order = 40, position = 5)
   private final date startDate;

   /** To Date */
   @LegacyField(fieldId = 5, name = "end-date", format = "99/99/99", initial = "?", columnLabel = "To Date", label = "To Date", order = 50, position = 6)
   private final date endDate;

   /**
    * Default constructor.
    */
   public RateImpl()
   {
      typeOfRoom = new integer(0);
      floor = new integer(0);
      rate = new decimal(0, 2);
      startDate = new date();
      endDate = new date();
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new RateImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from the given, backup
    * instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      RateImpl from = (RateImpl) old;
      setId(from.id);
      setTypeOfRoom(from.typeOfRoom);
      setFloor(from.floor);
      setRate(from.rate);
      setStartDate(from.startDate);
      setEndDate(from.endDate);
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Type of Room
    * 
    * @return  Type of Room
    */
   public integer getTypeOfRoom()
   {
      return (new integer(typeOfRoom));
   }

   /**
    * Setter: Type of Room
    * 
    * @param   typeOfRoom
    *          Type of Room
    */
   public void setTypeOfRoom(NumberType typeOfRoom)
   {
      this.typeOfRoom.assign(typeOfRoom);
   }

   /**
    * Getter: Floor
    * 
    * @return  Floor
    */
   public integer getFloor()
   {
      return (new integer(floor));
   }

   /**
    * Setter: Floor
    * 
    * @param   floor
    *          Floor
    */
   public void setFloor(NumberType floor)
   {
      this.floor.assign(floor);
   }

   /**
    * Getter: Rate
    * 
    * @return  Rate
    */
   public decimal getRate()
   {
      return (new decimal(rate));
   }

   /**
    * Setter: Rate
    * 
    * @param   rate
    *          Rate
    */
   public void setRate(NumberType rate)
   {
      this.rate.assign(rate);
   }

   /**
    * Getter: From Date
    * 
    * @return  From Date
    */
   public date getStartDate()
   {
      return (new date(startDate));
   }

   /**
    * Setter: From Date
    * 
    * @param   startDate
    *          From Date
    */
   public void setStartDate(date startDate)
   {
      this.startDate.assign(startDate);
   }

   /**
    * Getter: To Date
    * 
    * @return  To Date
    */
   public date getEndDate()
   {
      return (new date(endDate));
   }

   /**
    * Setter: To Date
    * 
    * @param   endDate
    *          To Date
    */
   public void setEndDate(date endDate)
   {
      this.endDate.assign(endDate);
   }
}
